pub struct OutputCode(/* private fields */);Expand description
A status code the represents the outcome of a Rust-side function, intended to be sent back to GameMaker.
Implementations
Sourceimpl OutputCode
impl OutputCode
Sourcepub const SUCCESS: OutputCode
pub const SUCCESS: OutputCode
Represents an operation that executed as intended.
Sourcepub const FAILURE: OutputCode
pub const FAILURE: OutputCode
Represents an operation that failed to execute as intended.